@@ -518,36 +518,6 @@ assert_vars <- function(arg, expect_names = FALSE, optional = FALSE) {
   assert_list_of(arg, "symbol", named = expect_names, optional = optional)
 }
 
-#' Is an Argument a List of Order Variables?
-#'
-#' @description
-#' `r lifecycle::badge("deprecated")`
-#'
-#' This function is *deprecated*, please use `assert_expr_list()` instead.
-#'
-#' Checks if an argument is a valid list of order variables/expressions created
-#' using `exprs()`
-#'
-#' @param arg A function argument to be checked
-#' @param optional Is the checked argument optional? If set to `FALSE` and `arg`
-#' is `NULL` then an error is thrown
-#'
-#'
-#' @return
-#' The function throws an error if `arg` is not a list of variables or
-#' expressions created using `exprs()` and returns the input invisibly
-#' otherwise.
-#'
-#' @export
-#'
-#' @keywords deprecated
-#' @family deprecated
-assert_order_vars <- function(arg, optional = FALSE) {
-  assert_logical_scalar(optional)
-
-  deprecate_stop("0.4.0", "assert_order_vars()", "assert_expr_list()")
-}
-
 #' Is an Argument an Integer Scalar?
 #'
 #' Checks if an argument is an integer scalar
@@ -885,8 +855,7 @@ assert_named <- function(arg, optional = FALSE) {
 #'
 #' @export
 assert_named_exprs <- function(arg, optional = FALSE) {
-  deprecate_warn("0.5.0", "assert_named_exprs()", "assert_expr_list()", always = TRUE)
-  assert_expr_list(arg = arg, named = TRUE)
+  deprecate_stop("0.5.0", "assert_named_exprs()", "assert_expr_list()")
 }
 
 #' Does a Dataset Contain All Required Variables?
@@ -910,14 +879,7 @@ assert_named_exprs <- function(arg, optional = FALSE) {
 #' @keywords deprecated
 #' @family deprecated
 assert_has_variables <- function(dataset, required_vars) {
-  deprecate_warn("0.5.0", "assert_has_variables()", "assert_data_frame()")
-  assert_data_frame(
-    arg = dataset,
-    required_vars = set_names(
-      exprs(!!!syms(required_vars)),
-      names(required_vars)
-    )
-  )
+  deprecate_stop("0.5.0", "assert_has_variables()", "assert_data_frame()")
 }
 
 #' Is Argument a Function?
@@ -925,14 +887,15 @@ assert_has_variables <- function(dataset, required_vars) {
 #' Checks if the argument is a function and if all expected arguments are
 #' provided by the function.
 #'
-#' @description
-#' `r lifecycle::badge("deprecated")`
+#' @param arg A function
 #'
-#' This function is *deprecated*, please use `assert_function_param()` instead.
+#' The function to be checked
 #'
-#' @param arg A function argument to be checked
+#' @param params A character vector
 #'
-#' @param params A character vector of expected argument names
+#' A character vector of expected argument names for the aforementioned function in `arg`.
+#' If ellipsis, `...`, is included in the function formals of the function in `arg`,
+#' this argument, `params` will be ignored, accepting all values of the character vector.
 #'
 #' @param optional Is the checked argument optional?
 #'
@@ -944,12 +907,13 @@ assert_has_variables <- function(dataset, required_vars) {
 #'  - if the argument is not a function or
 #'
 #'  - if the function does not provide all arguments as specified for the
-#'  `params` argument.
+#'  `params` argument (assuming ellipsis is not in function formals)
 #'
 #' @export
 #'
-#' @keywords deprecated
-#' @family deprecated
+#' @keywords assertion
+#' @family assertion
+#'
 #' @examples
 #' example_fun <- function(fun) {
 #'   assert_function(fun, params = c("x"))
@@ -985,6 +949,9 @@ assert_function <- function(arg, params = NULL, optional = FALSE) {
     abort(err_msg)
   }
   if (!is.null(params)) {
+    if ("..." %in% names(formals(arg))) {
+      return(invisible(arg))
+    }
     is_param <- params %in% names(formals(arg))
     if (!all(is_param)) {
       txt <- if (sum(!is_param) == 1L) {
@@ -1001,11 +968,16 @@ assert_function <- function(arg, params = NULL, optional = FALSE) {
 
 #' Assert Argument is a Parameter of a Function
 #'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' This function is *deprecated*, please use `assert_function()` instead.
+#'
 #' @param arg The name of a function passed as a string
 #' @param params A character vector of function parameters
 #'
-#' @keywords assertion
-#' @family assertion
+#' @keywords deprecated
+#' @family deprecated
 #'
 #' @return
 #' The function throws an error if any elements of `params` is not an argument of
@@ -1013,8 +985,7 @@ assert_function <- function(arg, params = NULL, optional = FALSE) {
 #'
 #' @export
 assert_function_param <- function(arg, params) {
-  deprecate_warn("0.5.0", "assert_function_param()", "assert_function()", always = TRUE)
-  assert_function(arg = arg, params = params)
+  deprecate_stop("0.5.0", "assert_function_param()", "assert_function()")
 }
 
 #' Asserts That a Parameter is Provided in the Expected Unit
