@@ -1,6 +1,5 @@
-# ---- addin_format_testthat, test 1: works as expected ----
-test_that("addin_format_testthat, test 1: works as expected", {
-
+## Test 1: works as expected ----
+test_that("addin_format_testthat Test 1: works as expected", {
   # test: file exists
   expect_error(
     prepare_test_that_file("file_does_not_exist"),
@@ -36,12 +35,11 @@ test_that("addin_format_testthat, test 1: works as expected", {
     file_content = c(
       "# some stuff in comment",
       paste0(
-        "# ---- ", sub("test-", "", basename(tf)), ", ",
-        "test 1: my description ----"
+        "## Test 1: my description ----"
       ),
       paste0(
-        'test_that("', sub("test-", "", basename(tf)), ", ",
-        'test 1: my description", {'
+        'test_that("', sub("test-", "", basename(tf)), " ",
+        'Test 1: my description", {'
       ),
       "  expect_true(TRUE)",
       "}"
