@@ -1,32 +1,32 @@
 # assert_has_variables ----
-## Test 1: error if a required variable is missing (deprecation warn) ----
-test_that("assert_has_variables Test 1: error if a required variable is missing (deprecation warn)", { # nolint
+## Test 1: error if a required variable is missing (deprecation error) ----
+test_that("assert_has_variables Test 1: error if a required variable is missing (deprecation error)", { # nolint
   data <- tibble::tribble(
     ~USUBJID,
     "1"
   )
 
-  expect_warning(
-    try(assert_has_variables(data, "TRT01P"), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    assert_has_variables(data, "TRT01P"),
+    class = "lifecycle_error_deprecated"
   )
 
-  expect_warning(
-    try(assert_has_variables(pharmaversesdtm::dm, c("TRT01P", "AVAL")), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    assert_has_variables(pharmaversesdtm::dm, c("TRT01P", "AVAL")),
+    class = "lifecycle_error_deprecated"
   )
 })
 
-## Test 2: no error if a required variable exists (deprecation warn) ----
-test_that("assert_has_variables Test 2: no error if a required variable exists (deprecation warn)", { # nolint
+## Test 2: no error if a required variable exists (deprecation error) ----
+test_that("assert_has_variables Test 2: no error if a required variable exists (deprecation error)", { # nolint
   data <- tibble::tribble(
     ~USUBJID,
     "1"
   )
 
-  expect_warning(
-    try(assert_has_variables(data, "USUBJID"), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    assert_has_variables(data, "USUBJID"),
+    class = "lifecycle_error_deprecated"
   )
 })
 
@@ -492,18 +492,9 @@ test_that("assert_vars Test 31: error if some elements of `arg` are not unquoted
   )
 })
 
-# assert_order_vars ----
-## Test 32: warn if assert_order_vars() is called ----
-test_that("assert_order_vars Test 32: warn if assert_order_vars() is called", {
-  expect_error(
-    assert_order_vars(arg <- exprs(USUBJID)),
-    class = "lifecycle_error_deprecated"
-  )
-})
-
 # assert_integer_scalar ----
-## Test 33: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_integer_scalar Test 33: no error if `arg` is NULL and optional is TRUE", {
+## Test 32: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_integer_scalar Test 32: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, optional = TRUE)
   }
@@ -513,8 +504,8 @@ test_that("assert_integer_scalar Test 33: no error if `arg` is NULL and optional
   )
 })
 
-## Test 34: error if chosen subset not in subsets ----
-test_that("assert_integer_scalar Test 34: error if chosen subset not in subsets", {
+## Test 33: error if chosen subset not in subsets ----
+test_that("assert_integer_scalar Test 33: error if chosen subset not in subsets", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, subset = "infinity")
   }
@@ -524,8 +515,8 @@ test_that("assert_integer_scalar Test 34: error if chosen subset not in subsets"
   )
 })
 
-## Test 35: no error if `arg` is in selected subset ----
-test_that("assert_integer_scalar Test 35: no error if `arg` is in selected subset", {
+## Test 34: no error if `arg` is in selected subset ----
+test_that("assert_integer_scalar Test 34: no error if `arg` is in selected subset", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg, subset = "positive")
   }
@@ -535,8 +526,8 @@ test_that("assert_integer_scalar Test 35: no error if `arg` is in selected subse
   )
 })
 
-## Test 36: error if `arg` is not an integer scalar ----
-test_that("assert_integer_scalar Test 36: error if `arg` is not an integer scalar", {
+## Test 35: error if `arg` is not an integer scalar ----
+test_that("assert_integer_scalar Test 35: error if `arg` is not an integer scalar", {
   example_fun <- function(arg) {
     assert_integer_scalar(arg)
   }
@@ -550,8 +541,8 @@ test_that("assert_integer_scalar Test 36: error if `arg` is not an integer scala
 })
 
 # assert_numeric_vector ----
-## Test 37: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_numeric_vector Test 37: no error if `arg` is NULL and optional is TRUE", {
+## Test 36: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_numeric_vector Test 36: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_numeric_vector(arg, optional = TRUE)
   }
@@ -562,8 +553,8 @@ test_that("assert_numeric_vector Test 37: no error if `arg` is NULL and optional
 })
 
 # assert_integer_scalar ----
-## Test 38: error if `arg` is not an integer scalar ----
-test_that("assert_integer_scalar Test 38: error if `arg` is not an integer scalar", {
+## Test 37: error if `arg` is not an integer scalar ----
+test_that("assert_integer_scalar Test 37: error if `arg` is not an integer scalar", {
   example_fun <- function(arg) {
     assert_numeric_vector(arg)
   }
@@ -576,8 +567,8 @@ test_that("assert_integer_scalar Test 38: error if `arg` is not an integer scala
 })
 
 # assert_s3_class ----
-## Test 39: error if `arg` is not an object of a specific class S3 ----
-test_that("assert_s3_class Test 39: error if `arg` is not an object of a specific class S3", {
+## Test 38: error if `arg` is not an object of a specific class S3 ----
+test_that("assert_s3_class Test 38: error if `arg` is not an object of a specific class S3", {
   example_fun <- function(arg) {
     assert_s3_class(arg, "factor")
   }
@@ -585,8 +576,8 @@ test_that("assert_s3_class Test 39: error if `arg` is not an object of a specifi
   expect_error(example_fun("test"))
 })
 
-## Test 40: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_s3_class Test 40: no error if `arg` is NULL and optional is TRUE", {
+## Test 39: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_s3_class Test 39: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_s3_class(arg, class = "factor", optional = TRUE)
   }
@@ -596,8 +587,8 @@ test_that("assert_s3_class Test 40: no error if `arg` is NULL and optional is TR
   )
 })
 
-## Test 41: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_s3_class Test 41: error if `arg` is NULL and optional is FALSE", {
+## Test 40: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_s3_class Test 40: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_s3_class(arg, class = "factor", optional = FALSE)
   }
@@ -609,8 +600,8 @@ test_that("assert_s3_class Test 41: error if `arg` is NULL and optional is FALSE
   )
 })
 
-## Test 42: no error if `arg` is an object of a specific class S3 ----
-test_that("assert_s3_class Test 42: no error if `arg` is an object of a specific class S3", {
+## Test 41: no error if `arg` is an object of a specific class S3 ----
+test_that("assert_s3_class Test 41: no error if `arg` is an object of a specific class S3", {
   example_fun <- function(arg) {
     assert_s3_class(arg, "factor")
   }
@@ -619,8 +610,8 @@ test_that("assert_s3_class Test 42: no error if `arg` is an object of a specific
 })
 
 # assert_list_of ----
-## Test 43: error if `arg` is not a list of specific class S3 objects ----
-test_that("assert_list_of Test 43: error if `arg` is not a list of specific class S3 objects", {
+## Test 42: error if `arg` is not a list of specific class S3 objects ----
+test_that("assert_list_of Test 42: error if `arg` is not a list of specific class S3 objects", {
   example_fun <- function(arg) {
     assert_list_of(arg, "factor")
   }
@@ -628,8 +619,8 @@ test_that("assert_list_of Test 43: error if `arg` is not a list of specific clas
   expect_error(example_fun(list("test")))
 })
 
-## Test 44: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_list_of Test 44: no error if `arg` is NULL and optional is TRUE", {
+## Test 43: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_list_of Test 43: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_list_of(arg, class = "factor", optional = TRUE)
   }
@@ -639,8 +630,8 @@ test_that("assert_list_of Test 44: no error if `arg` is NULL and optional is TRU
   )
 })
 
-## Test 45: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_list_of Test 45: error if `arg` is NULL and optional is FALSE", {
+## Test 44: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_list_of Test 44: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_list_of(arg, class = "factor", optional = FALSE)
   }
@@ -652,8 +643,8 @@ test_that("assert_list_of Test 45: error if `arg` is NULL and optional is FALSE"
   )
 })
 
-## Test 46: no error if `arg` is a list of specific class S3 objects ----
-test_that("assert_list_of Test 46: no error if `arg` is a list of specific class S3 objects", {
+## Test 45: no error if `arg` is a list of specific class S3 objects ----
+test_that("assert_list_of Test 45: no error if `arg` is a list of specific class S3 objects", {
   example_fun <- function(arg) {
     assert_list_of(arg, "factor")
   }
@@ -665,8 +656,8 @@ test_that("assert_list_of Test 46: no error if `arg` is a list of specific class
   )
 })
 
-## Test 47: error if `arg` is not a named list (no elements named) ----
-test_that("assert_list_of Test 47: error if `arg` is not a named list (no elements named)", {
+## Test 46: error if `arg` is not a named list (no elements named) ----
+test_that("assert_list_of Test 46: error if `arg` is not a named list (no elements named)", {
   expect_error(
     assert_list_of(mylist <- list(1, 2, 3), class = "numeric", named = TRUE),
     paste(
@@ -677,8 +668,8 @@ test_that("assert_list_of Test 47: error if `arg` is not a named list (no elemen
   )
 })
 
-## Test 48: error if `arg` is not a named list (some elements named) ----
-test_that("assert_list_of Test 48: error if `arg` is not a named list (some elements named)", {
+## Test 47: error if `arg` is not a named list (some elements named) ----
+test_that("assert_list_of Test 47: error if `arg` is not a named list (some elements named)", {
   expect_error(
     assert_list_of(mylist <- list(1, 2, 3, d = 4), class = "numeric", named = TRUE),
     paste(
@@ -689,21 +680,21 @@ test_that("assert_list_of Test 48: error if `arg` is not a named list (some elem
   )
 })
 
-## Test 49: no error if `arg` is a named list ----
-test_that("assert_list_of Test 49: no error if `arg` is a named list", {
+## Test 48: no error if `arg` is a named list ----
+test_that("assert_list_of Test 48: no error if `arg` is a named list", {
   expect_invisible(
     assert_list_of(mylist <- list(a = 1, b = 2, c = 3), class = "numeric", named = TRUE)
   )
 })
 
 # assert_named ----
-## Test 50: no error if arg is NULL and optional = TRUE ----
-test_that("assert_named Test 50: no error if arg is NULL and optional = TRUE", {
+## Test 49: no error if arg is NULL and optional = TRUE ----
+test_that("assert_named Test 49: no error if arg is NULL and optional = TRUE", {
   expect_invisible(assert_named(arg <- NULL, optional = TRUE))
 })
 
-## Test 51: error if no elements are named ----
-test_that("assert_named Test 51: error if no elements are named", {
+## Test 50: error if no elements are named ----
+test_that("assert_named Test 50: error if no elements are named", {
   expect_error(
     assert_named(arg <- c(1, 2)),
     regexp = paste(
@@ -716,8 +707,8 @@ test_that("assert_named Test 51: error if no elements are named", {
 })
 
 # assert_named_exprs ----
-## Test 52: error if `arg` is not a named list of expressions (deprecation warn) ----
-test_that("assert_named_exprs Test 52: error if `arg` is not a named list of expressions (deprecation warn)", { # nolint
+## Test 51: error if `arg` is not a named list of expressions (deprecation error) ----
+test_that("assert_named_exprs Test 51: error if `arg` is not a named list of expressions (deprecation error)", { # nolint
   example_fun <- function(arg) {
     assert_named_exprs(arg)
   }
@@ -725,56 +716,51 @@ test_that("assert_named_exprs Test 52: error if `arg` is not a named list of exp
   arg <- list("test")
   names(arg) <- c("")
 
-  expect_warning(
-    try(example_fun(5), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(5),
+    class = "lifecycle_error_deprecated"
   )
-  expect_warning(
-    try(example_fun(pharmaversesdtm::dm), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(pharmaversesdtm::dm),
+    class = "lifecycle_error_deprecated"
   )
-  expect_warning(
-    try(example_fun(list(1, 2, TRUE)), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(list(1, 2, TRUE)),
+    class = "lifecycle_error_deprecated"
   )
-  expect_warning(
-    try(example_fun(arg), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(arg),
+    class = "lifecycle_error_deprecated"
   )
 })
 
-## Test 53: no error if `arg` is NULL and optional is TRUE (deprecation warn) ----
-test_that("assert_named_exprs Test 53: no error if `arg` is NULL and optional is TRUE (deprecation warn)", { # nolint
+## Test 52: no error if `arg` is NULL and optional is TRUE (deprecation error) ----
+test_that("assert_named_exprs Test 52: no error if `arg` is NULL and optional is TRUE (deprecation error)", { # nolint
   example_fun <- function(arg) {
     assert_named_exprs(arg, optional = TRUE)
   }
 
-  expect_warning(
-    try(example_fun(NULL), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(NULL),
+    class = "lifecycle_error_deprecated"
   )
 })
 
-## Test 54: no error if `arg` is a named list of expressions (deprecation warn) ----
-test_that("assert_named_exprs Test 54: no error if `arg` is a named list of expressions (deprecation warn)", { # nolint
+## Test 53: no error if `arg` is a named list of expressions (deprecation error) ----
+test_that("assert_named_exprs Test 53: no error if `arg` is a named list of expressions (deprecation error)", { # nolint
   example_fun <- function(arg) {
     assert_named_exprs(arg)
   }
 
-  expect_warning(
-    try(
-      example_fun(
-        rlang::exprs()
-      ),
-      silent = TRUE
-    ),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    example_fun(rlang::exprs()),
+    class = "lifecycle_error_deprecated"
   )
 })
 
 # assert_function ----
-## Test 55: error if `arg` is not a function ----
-test_that("assert_function Test 55: error if `arg` is not a function", {
+## Test 54: error if `arg` is not a function ----
+test_that("assert_function Test 54: error if `arg` is not a function", {
   example_fun <- function(arg) {
     assert_function(arg)
   }
@@ -783,8 +769,8 @@ test_that("assert_function Test 55: error if `arg` is not a function", {
   expect_error(example_fun())
 })
 
-## Test 56: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_function Test 56: no error if `arg` is NULL and optional is TRUE", {
+## Test 55: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_function Test 55: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_function(arg, optional = TRUE)
   }
@@ -794,8 +780,8 @@ test_that("assert_function Test 56: no error if `arg` is NULL and optional is TR
   )
 })
 
-## Test 57: no error if `arg` is a function with all parameters defined ----
-test_that("assert_function Test 57: no error if `arg` is a function with all parameters defined", {
+## Test 56: no error if `arg` is a function with all parameters defined ----
+test_that("assert_function Test 56: no error if `arg` is a function with all parameters defined", {
   example_fun <- function(arg) {
     assert_function(arg, params = c("x"))
   }
@@ -803,8 +789,8 @@ test_that("assert_function Test 57: no error if `arg` is a function with all par
   expect_invisible(example_fun(mean))
 })
 
-## Test 58: error if  `params`  is missing with no default ----
-test_that("assert_function Test 58: error if  `params`  is missing with no default", {
+## Test 57: error if  `params`  is missing with no default ----
+test_that("assert_function Test 57: error if  `params`  is missing with no default", {
   example_fun <- function(arg) {
     assert_function(arg, params = c("x"))
   }
@@ -818,39 +804,49 @@ test_that("assert_function Test 58: error if  `params`  is missing with no defau
   expect_error(example_fun(sum))
 })
 
+## Test 59: If dot-dot-dot is a argument ----
+test_that("assert_function Test 59: If dot-dot-dot is a argument", {
+  example_fun <- function(derivation, args = NULL) {
+    assert_function(derivation, names(args))
+  }
+  expect_invisible(example_fun(mutate, args = exprs(AVAL = x + 1)))
+})
+
+
 
 # assert_function_param ----
-## Test 59: no error if `arg` is a parameter of a function (deprecation warn) ----
-test_that("assert_function_param Test 59: no error if `arg` is a parameter of a function (deprecation warn)", { # nolint
+## Test 58: no error if `arg` is a parameter of a function (deprecation error) ----
+test_that("assert_function_param Test 58: no error if `arg` is a parameter of a function (deprecation error)", { # nolint
   hello <- function(name) {
     print(sprintf("Hello %s", name))
   }
 
-  expect_warning(
-    try(assert_function_param("hello", params = "name"), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    assert_function_param("hello", params = "name"),
+    class = "lifecycle_error_deprecated"
   )
 })
 
-## Test 60: error if expected function parameters are missing (deprecation warn) ----
-test_that("assert_function_param Test 60: error if expected function parameters are missing (deprecation warn)", { # nolint
+## Test 59: error if expected function parameters are missing (deprecation error) ----
+test_that("assert_function_param Test 59: error if expected function parameters are missing (deprecation error)", { # nolint
   hello <- function(name) {
     print(sprintf("Hello %s", name))
   }
 
-  expect_warning(
-    try(assert_function_param("hello", "surname"), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+  expect_error(
+    assert_function_param("hello", "surname"),
+    class = "lifecycle_error_deprecated"
   )
-  expect_warning(
-    try(assert_function_param("hello", params = c("surname", "firstname")), silent = TRUE),
-    class = "lifecycle_warning_deprecated"
+
+  expect_error(
+    assert_function_param("hello", params = c("surname", "firstname")),
+    class = "lifecycle_error_deprecated"
   )
 })
 
 # assert_unit ----
-## Test 61: no error if the parameter is provided in the expected unit ----
-test_that("assert_unit Test 61: no error if the parameter is provided in the expected unit", {
+## Test 60: no error if the parameter is provided in the expected unit ----
+test_that("assert_unit Test 60: no error if the parameter is provided in the expected unit", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -862,8 +858,8 @@ test_that("assert_unit Test 61: no error if the parameter is provided in the exp
   )
 })
 
-## Test 62: error if there are multiple units in the input dataset ----
-test_that("assert_unit Test 62: error if there are multiple units in the input dataset", {
+## Test 61: error if there are multiple units in the input dataset ----
+test_that("assert_unit Test 61: error if there are multiple units in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -875,8 +871,8 @@ test_that("assert_unit Test 62: error if there are multiple units in the input d
   )
 })
 
-## Test 63: error if unexpected unit in the input dataset ----
-test_that("assert_unit Test 63: error if unexpected unit in the input dataset", {
+## Test 62: error if unexpected unit in the input dataset ----
+test_that("assert_unit Test 62: error if unexpected unit in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -889,8 +885,8 @@ test_that("assert_unit Test 63: error if unexpected unit in the input dataset",
 })
 
 # assert_param_does_not_exist ----
-## Test 64: error if parameter exists in the input dataset ----
-test_that("assert_param_does_not_exist Test 64: error if parameter exists in the input dataset", {
+## Test 63: error if parameter exists in the input dataset ----
+test_that("assert_param_does_not_exist Test 63: error if parameter exists in the input dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -902,8 +898,8 @@ test_that("assert_param_does_not_exist Test 64: error if parameter exists in the
   )
 })
 
-## Test 65: no error if the parameter exists in the dataset ----
-test_that("assert_param_does_not_exist Test 65: no error if the parameter exists in the dataset", {
+## Test 64: no error if the parameter exists in the dataset ----
+test_that("assert_param_does_not_exist Test 64: no error if the parameter exists in the dataset", {
   advs <- tibble::tribble(
     ~USUBJID, ~VSTESTCD, ~VSTRESN, ~VSSTRESU, ~PARAMCD, ~AVAL,
     "P01",    "WEIGHT",      80.1, "kg",      "WEIGHT",  80.1,
@@ -916,8 +912,8 @@ test_that("assert_param_does_not_exist Test 65: no error if the parameter exists
 })
 
 # assert_varval_list ----
-## Test 66: error if `arg` is not a list of var-value expressions ----
-test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value expressions", {
+## Test 65: error if `arg` is not a list of var-value expressions ----
+test_that("assert_varval_list Test 65: error if `arg` is not a list of var-value expressions", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_var = FALSE)
   }
@@ -927,8 +923,8 @@ test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value
   )
 })
 
-## Test 67: error if `arg` is not a list of var-value expressions ----
-test_that("assert_varval_list Test 67: error if `arg` is not a list of var-value expressions", {
+## Test 66: error if `arg` is not a list of var-value expressions ----
+test_that("assert_varval_list Test 66: error if `arg` is not a list of var-value expressions", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_var = TRUE)
   }
@@ -938,8 +934,8 @@ test_that("assert_varval_list Test 67: error if `arg` is not a list of var-value
   )
 })
 
-## Test 68: error if `required_elements` are missing from `arg` ----
-test_that("assert_varval_list Test 68: error if `required_elements` are missing from `arg`", {
+## Test 67: error if `required_elements` are missing from `arg` ----
+test_that("assert_varval_list Test 67: error if `required_elements` are missing from `arg`", {
   example_fun <- function(arg) {
     assert_varval_list(arg, required_elements = "DTHDOM")
   }
@@ -949,8 +945,8 @@ test_that("assert_varval_list Test 68: error if `required_elements` are missing
   )
 })
 
-## Test 69: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_varval_list Test 69: no error if `arg` is NULL and optional is TRUE", {
+## Test 68: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_varval_list Test 68: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_varval_list(arg, optional = TRUE)
   }
@@ -960,8 +956,8 @@ test_that("assert_varval_list Test 69: no error if `arg` is NULL and optional is
   )
 })
 
-## Test 70: error if `accept_expr` is TRUE and value is invalid ----
-test_that("assert_varval_list Test 70: error if `accept_expr` is TRUE and value is invalid", {
+## Test 69: error if `accept_expr` is TRUE and value is invalid ----
+test_that("assert_varval_list Test 69: error if `accept_expr` is TRUE and value is invalid", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_expr = TRUE)
   }
@@ -971,8 +967,8 @@ test_that("assert_varval_list Test 70: error if `accept_expr` is TRUE and value
   )
 })
 
-## Test 71: error if `accept_expr` is FALSE and value is invalid ----
-test_that("assert_varval_list Test 71: error if `accept_expr` is FALSE and value is invalid", {
+## Test 70: error if `accept_expr` is FALSE and value is invalid ----
+test_that("assert_varval_list Test 70: error if `accept_expr` is FALSE and value is invalid", {
   example_fun <- function(arg) {
     assert_varval_list(arg, accept_expr = FALSE)
   }
@@ -982,8 +978,8 @@ test_that("assert_varval_list Test 71: error if `accept_expr` is FALSE and value
   )
 })
 
-## Test 72: no error if an argument is a variable-value list ----
-test_that("assert_varval_list Test 72: no error if an argument is a variable-value list", {
+## Test 71: no error if an argument is a variable-value list ----
+test_that("assert_varval_list Test 71: no error if an argument is a variable-value list", {
   example_fun <- function(arg) {
     assert_varval_list(arg)
   }
@@ -994,8 +990,8 @@ test_that("assert_varval_list Test 72: no error if an argument is a variable-val
 })
 
 # assert_expr_list ----
-## Test 73: error if `arg` is not a list of expressions ----
-test_that("assert_expr_list Test 73: error if `arg` is not a list of expressions", {
+## Test 72: error if `arg` is not a list of expressions ----
+test_that("assert_expr_list Test 72: error if `arg` is not a list of expressions", {
   expect_error(
     assert_expr_list(arg <- c("USUBJID", "PARAMCD", "VISIT")),
     regexp = "`arg` must be a named list of expressions but it is a",
@@ -1003,8 +999,8 @@ test_that("assert_expr_list Test 73: error if `arg` is not a list of expressions
   )
 })
 
-## Test 74: error if `arg` is not a named list of expressions ----
-test_that("assert_expr_list Test 74: error if `arg` is not a named list of expressions", {
+## Test 73: error if `arg` is not a named list of expressions ----
+test_that("assert_expr_list Test 73: error if `arg` is not a named list of expressions", {
   expect_error(
     assert_expr_list(arg <- exprs(USUBJID, PARAMCD, NULL), named = TRUE),
     regexp = "All elements of `arg` must be named.",
@@ -1012,8 +1008,8 @@ test_that("assert_expr_list Test 74: error if `arg` is not a named list of expre
   )
 })
 
-## Test 75: error if `required_elements` are missing from `arg` ----
-test_that("assert_expr_list Test 75: error if `required_elements` are missing from `arg`", {
+## Test 74: error if `required_elements` are missing from `arg` ----
+test_that("assert_expr_list Test 74: error if `required_elements` are missing from `arg`", {
   expect_error(
     assert_expr_list(
       arg <- exprs(DTHSEQ = AESEQ),
@@ -1024,15 +1020,15 @@ test_that("assert_expr_list Test 75: error if `required_elements` are missing fr
   )
 })
 
-## Test 76: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_expr_list Test 76: no error if `arg` is NULL and optional is TRUE", {
+## Test 75: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_expr_list Test 75: no error if `arg` is NULL and optional is TRUE", {
   expect_invisible(
     assert_expr_list(NULL, optional = TRUE)
   )
 })
 
-## Test 77: error if element is invalid ----
-test_that("assert_expr_list Test 77: error if element is invalid", {
+## Test 76: error if element is invalid ----
+test_that("assert_expr_list Test 76: error if element is invalid", {
   expect_error(
     assert_expr_list(arg <- exprs(DTHSEQ = !!mean)),
     regexp = "All elements of `arg` must be an expression.",
@@ -1040,8 +1036,8 @@ test_that("assert_expr_list Test 77: error if element is invalid", {
   )
 })
 
-## Test 78: no error if argument is valid ----
-test_that("assert_expr_list Test 78: no error if argument is valid", {
+## Test 77: no error if argument is valid ----
+test_that("assert_expr_list Test 77: no error if argument is valid", {
   expect_invisible(
     assert_expr_list(arg <- exprs(
       DTHDOM = "AE",
@@ -1052,8 +1048,8 @@ test_that("assert_expr_list Test 78: no error if argument is valid", {
 })
 
 # assert_list_element ----
-## Test 79: no error if the elements fulfill a certain condition ----
-test_that("assert_list_element Test 79: no error if the elements fulfill a certain condition", {
+## Test 78: no error if the elements fulfill a certain condition ----
+test_that("assert_list_element Test 78: no error if the elements fulfill a certain condition", {
   expect_invisible(
     assert_list_element(
       list(
@@ -1067,8 +1063,8 @@ test_that("assert_list_element Test 79: no error if the elements fulfill a certa
   )
 })
 
-## Test 80: error if the elements do not fulfill the condition ----
-test_that("assert_list_element Test 80: error if the elements do not fulfill the condition", {
+## Test 79: error if the elements do not fulfill the condition ----
+test_that("assert_list_element Test 79: error if the elements do not fulfill the condition", {
   expect_error(
     assert_list_element(
       input <- list(
@@ -1085,16 +1081,16 @@ test_that("assert_list_element Test 80: error if the elements do not fulfill the
 })
 
 # assert_one_to_one ----
-## Test 81: error if there is a one to many mapping ----
-test_that("assert_one_to_one Test 81: error if there is a one to many mapping", {
+## Test 80: error if there is a one to many mapping ----
+test_that("assert_one_to_one Test 80: error if there is a one to many mapping", {
   expect_error(
     assert_one_to_one(pharmaversesdtm::dm, exprs(DOMAIN), exprs(USUBJID))
   )
   admiraldev_environment$one_to_many <- NULL
 })
 
-## Test 82: error if there is a many to one mapping ----
-test_that("assert_one_to_one Test 82: error if there is a many to one mapping", {
+## Test 81: error if there is a many to one mapping ----
+test_that("assert_one_to_one Test 81: error if there is a many to one mapping", {
   expect_error(
     assert_one_to_one(pharmaversesdtm::dm, exprs(USUBJID), exprs(DOMAIN))
   )
@@ -1102,8 +1098,8 @@ test_that("assert_one_to_one Test 82: error if there is a many to one mapping",
 })
 
 # assert_date_var ----
-## Test 83: error if variable is not a date or datetime variable ----
-test_that("assert_date_var Test 83: error if variable is not a date or datetime variable", {
+## Test 82: error if variable is not a date or datetime variable ----
+test_that("assert_date_var Test 82: error if variable is not a date or datetime variable", {
   example_fun <- function(dataset, var) {
     var <- assert_symbol(enexpr(var))
     assert_date_var(dataset = dataset, var = !!var)
@@ -1124,18 +1120,18 @@ test_that("assert_date_var Test 83: error if variable is not a date or datetime
 })
 
 # assert_date_vector ----
-## Test 84: returns error if input vector is not a date formatted ----
-test_that("assert_date_vector Test 84: returns error if input vector is not a date formatted", {
+## Test 83: returns error if input vector is not a date formatted ----
+test_that("assert_date_vector Test 83: returns error if input vector is not a date formatted", {
   expect_error(assert_date_vector("2018-08-23"))
 })
 
-## Test 85: returns invisible if input is date formatted ----
-test_that("assert_date_vector Test 85: returns invisible if input is date formatted", {
+## Test 84: returns invisible if input is date formatted ----
+test_that("assert_date_vector Test 84: returns invisible if input is date formatted", {
   expect_invisible(assert_date_vector(as.Date("2022-10-25")))
 })
 
-## Test 86: no error if `arg` is NULL and optional is TRUE ----
-test_that("assert_date_vector Test 86: no error if `arg` is NULL and optional is TRUE", {
+## Test 85: no error if `arg` is NULL and optional is TRUE ----
+test_that("assert_date_vector Test 85: no error if `arg` is NULL and optional is TRUE", {
   example_fun <- function(arg) {
     assert_date_vector(arg, optional = TRUE)
   }
@@ -1145,8 +1141,8 @@ test_that("assert_date_vector Test 86: no error if `arg` is NULL and optional is
   )
 })
 
-## Test 87: error if `arg` is NULL and optional is FALSE ----
-test_that("assert_date_vector Test 87: error if `arg` is NULL and optional is FALSE", {
+## Test 86: error if `arg` is NULL and optional is FALSE ----
+test_that("assert_date_vector Test 86: error if `arg` is NULL and optional is FALSE", {
   example_fun <- function(arg) {
     assert_date_vector(arg, optional = FALSE)
   }
@@ -1160,22 +1156,22 @@ test_that("assert_date_vector Test 87: error if `arg` is NULL and optional is FA
 
 
 # assert_atomic_vector ----
-## Test 88: error if input is not atomic vector ----
-test_that("assert_atomic_vector Test 88: error if input is not atomic vector", {
+## Test 87: error if input is not atomic vector ----
+test_that("assert_atomic_vector Test 87: error if input is not atomic vector", {
   x <- list("a", "a", "b", "c", "d", "d", 1, 1, 4)
   expect_error(assert_atomic_vector(x))
 })
 
 # assert_same_type ----
-## Test 89: no error if same type ----
-test_that("assert_same_type Test 89: no error if same type", {
+## Test 88: no error if same type ----
+test_that("assert_same_type Test 88: no error if same type", {
   true_value <- "Y"
   false_value <- "N"
   expect_invisible(assert_same_type(true_value, false_value))
 })
 
-## Test 90: error if different type ----
-test_that("assert_same_type Test 90: error if different type", {
+## Test 89: error if different type ----
+test_that("assert_same_type Test 89: error if different type", {
   true_value <- "Y"
   false_value <- "N"
   missing_value <- 0
@@ -1194,8 +1190,8 @@ test_that("assert_same_type Test 90: error if different type", {
   )
 })
 
-## Test 91: works as intended ----
-test_that("assert_same_type Test 91: works as intended", {
+## Test 90: works as intended ----
+test_that("assert_same_type Test 90: works as intended", {
   expect_equal(
     valid_time_units(),
     c("years", "months", "days", "hours", "minutes", "seconds")
